@@ -177,7 +177,7 @@ KFileMetaDataProvider::Private::Private(KFileMetaDataProvider* parent) :
     q(parent)
 {
 #ifndef KIO_NO_NEPOMUK
-    m_nepomukActivated = (Nepomuk::ResourceManager::instance()->init() == 0);
+    m_nepomukActivated = Nepomuk::ResourceManager::instance()->initialized();
 #endif
 }
 
@@ -404,6 +404,7 @@ void KFileMetaDataProvider::setItems(const KFileItemList& items)
     }
 
     d->m_latestMetaDataReader = new KFileMetaDataReader(urls);
+    d->m_latestMetaDataReader->setReadContextData(d->m_nepomukActivated);
     connect(d->m_latestMetaDataReader, SIGNAL(finished()), this, SLOT(slotLoadingFinished()));
     d->m_metaDataReaders.append(d->m_latestMetaDataReader);
     d->m_latestMetaDataReader->start();
